@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -1313,6 +1314,9 @@ AppleKiwiIC::start(IOService *provider, UInt8* inBar5)
 		return false;
 	}
 
+	// remember this, as we will need it to call disable/enableInterrupt
+	myProvider = provider;
+
 	interruptControllerName = (OSSymbol *)IODTInterruptControllerName( provider );
 	if (interruptControllerName == 0) {
 		DLOG ("AppleKiwiIC::start - interruptControllerName is NULL\n");
@@ -1379,7 +1383,11 @@ IOInterruptAction
 AppleKiwiIC::getInterruptHandlerAddress(void)
 {
 
-	return  (IOInterruptAction) &AppleKiwiIC::handleInterrupt ;
+//	return  (IOInterruptAction) &AppleKiwiIC::handleInterrupt ;
+	// change for gcc 4
+	return  OSMemberFunctionCast(IOInterruptAction, this, &AppleKiwiIC::handleInterrupt) ;
+	
+
 
 }
 
@@ -1451,6 +1459,9 @@ AppleKiwiIC::initVector(long vectorNumber, IOInterruptVector *vector)
 void 
 AppleKiwiIC::disableVectorHard(long vectorNumber, IOInterruptVector *vector)
 {
+	myProvider->disableInterrupt( 0 );
+
+#if 0
 	switch( vectorNumber )
 	{
 		case 0:
@@ -1469,11 +1480,16 @@ AppleKiwiIC::disableVectorHard(long vectorNumber, IOInterruptVector *vector)
 
 
 }
+#endif
+}
+
 
 void 
 AppleKiwiIC::enableVector(long vectorNumber, IOInterruptVector *vector)
 {
+	myProvider->enableInterrupt( 0 );
 
+#if 0
 	switch( vectorNumber )
 	{
 		case 0:
@@ -1489,11 +1505,13 @@ AppleKiwiIC::enableVector(long vectorNumber, IOInterruptVector *vector)
 		default:
 		break; // ??? should not happen
 	}
+#endif
 
 
 
 }
 
+
 IOReturn 
 AppleKiwiIC::setPowerState ( unsigned long powerStateOrdinal, IOService* whatDevice )
 {
